diff --git a/containers/jug/eic-env.sh b/containers/jug/eic-env.sh
index 55e5e664c224bc8286f3a8ba31f82a5df5eb43c6..f4123dcce54193556f1e076633e75fe67165efbc 100755
--- a/containers/jug/eic-env.sh
+++ b/containers/jug/eic-env.sh
@@ -36,13 +36,16 @@ export PS1=${ps1_preamble}'\[\033[01;32m\]\u@\h\[\033[00m\]:\[\033[01;34m\]\w\[\
 export LS_COLORS='rs=0:di=01;34:ln=01;36:mh=00:pi=40;33'
 unset ps1_preamble
 
 ## unset CURL_CA_BUNDLE if not accessible inside container
 ## this addresses certain HPC systems where CURL_CA_BUNDLE
 ## is customized to point to paths that do not exist inside
 ## this container
 if [ ! -r ${CURL_CA_BUNDLE:-/} ]; then
   unset CURL_CA_BUNDLE
 fi
+if [ ! -r ${SSL_CERT_FILE:-/} ]; then
+  unset SSL_CERT_FILE
+fi
 
 ## redefine ls and less as functions, as this is something we
 ## can import into our plain bash --norc --noprofile session
@@ -36,13 +36,16 @@ export PS1=${ps1_preamble}'\[\033[01;32m\]\u@\h\[\033[00m\]:\[\033[01;34m\]\w\[\
 unset ps1_preamble
 
-## unset CURL_CA_BUNDLE if not accessible inside container
-## this addresses certain HPC systems where CURL_CA_BUNDLE
-## is customized to point to paths that do not exist inside
-## this container
+## unset CURL_CA_BUNDLE and SSL_CERT_FILE if not accessible
+## inside container: this addresses certain HPC systems where
+## CURL_CA_BUNDLE and SSL_CERT_FILE are customized to point
+## to paths that do not exist inside this container
 if [ ! -r ${CURL_CA_BUNDLE:-/} ]; then
   unset CURL_CA_BUNDLE